From ec5a4ed9ccb6f0e648dcb187a95b714d8124d66d Mon Sep 17 00:00:00 2001 From: Extraltodeus Date: Wed, 1 May 2024 20:48:48 +0200 Subject: [PATCH] Update README.md --- README.md | 2 +- 1 file changed, 1 insertion(+), 1 deletion(-) diff --git a/README.md b/README.md index 881cdcb..e6ce93a 100644 --- a/README.md +++ b/README.md @@ -95,7 +95,7 @@ Sample and Distribution Quality in Diffusion Models](https://arxiv.org/pdf/2404. # 10 steps with only 2 having the negative enabled. So ~170% faster. 2.5 seconds on a RTX4070 -![02871UI_00001_](https://github.com/Extraltodeus/ComfyUI-AutomaticCFG/assets/15731540/2edfbf05-0683-4c62-ad97-b21087325e7f) +![03640UI_00001_](https://github.com/Extraltodeus/ComfyUI-AutomaticCFG/assets/15731540/673cb47a-095f-4ebb-a186-2f6a49ffd2e1) # cherry-picked 24 steps uncond fully disabled (these images are also workflows):